pub enum MoleculeShape<'a> {
Spherical(usize),
NonSpherical(&'a DVector<f64>),
Heterosegmented(&'a DVector<usize>),
}Expand description
Different representations for molecules within DFT.
Variants
Spherical(usize)
For spherical molecules, the number of components.
NonSpherical(&'a DVector<f64>)
For non-spherical molecules in a homosegmented approach, the chain length parameter $m$.
Heterosegmented(&'a DVector<usize>)
For non-spherical molecules in a heterosegmented approach, the component index for every segment.