pub trait DFTSpecification<D: Dimension, F>: Send + Sync {
// Required method
fn calculate_bulk_density(
&self,
profile: &DFTProfile<D, F>,
bulk_density: &Array1<f64>,
z: &Array1<f64>,
) -> FeosResult<Array1<f64>>;
}Expand description
General specifications for the chemical potential in a DFT calculation.
In the most basic case, the chemical potential is specified in a DFT calculation, for more general systems, this trait provides the possibility to declare additional equations for the calculation of the chemical potential during the iteration.
Required Methods
fn calculate_bulk_density( &self, profile: &DFTProfile<D, F>, bulk_density: &Array1<f64>, z: &Array1<f64>, ) -> FeosResult<Array1<f64>>
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".